@@ -217,7 +217,7 @@ def download_from_S3(
     workspace_path: str,
     credentials: dict,
     destination_path: str,
-    copy_workspace_path: bool,
+    copy_workspace_path: bool = True,
 ) -> None:
     """
     Function to download file/folder from workspaces
